==> vue-create-web-0.1.0.tgz: package/es/components/controls/echarts/MixedChart.js <==
import "core-js/modules/es.function.name.js";
import "core-js/modules/es.object.keys.js";
import _classCallCheck from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/classCallCheck";
import _createClass from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/createClass";
import _inherits from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/inherits";
import _createSuper from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/createSuper";
import { __decorate } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import { mixins } from 'vue-class-component';
import BaseChart from './BaseChart';
import { withInstall } from '@/util';

var xAxisData = function () {
  var data = [];

  for (var i = 1; i < 13; i++) {
    data.push(i + 'month');
  }

  return data;
}();

var data = {
  female: [709, 1917, 2455, 2610, 1719, 1433, 1544, 3285, 5208, 3372, 2484, 4078],
  male: [327, 1776, 507, 1200, 800, 482, 204, 1390, 1001, 951, 381, 220],
  average: [1036, 3693, 2962, 3810, 2519, 1915, 1748, 4675, 6209, 4323, 2865, 4298]
};
export var defaultData = {
  xAxisData: xAxisData,
  data: data
};
export var defaultOption = {
  backgroundColor: '#344b58',
  title: {
    text: 'statistics',
    top: '20',
    textStyle: {
      color: '#fff',
      fontSize: 22
    },
    subtextStyle: {
      color: '#90979c',
      fontSize: 16
    }
  },
  tooltip: {
    trigger: 'axis'
  },
  grid: {
    left: '5%',
    right: '5%',
    borderWidth: 0,
    top: 150,
    bottom: 95,
    textStyle: {
      color: '#fff'
    }
  },
  legend: {
    x: '5%',
    top: '10%',
    textStyle: {
      color: '#90979c'
    },
    data: Object.keys(data)
  },
  xAxis: [{
    type: 'category',
    axisLine: {
      lineStyle: {
        color: '#90979c'
      }
    },
    splitLine: {
      show: false
    },
    axisTick: {
      show: false
    },
    splitArea: {
      show: false
    },
    axisLabel: {
      interval: 0
    },
    data: xAxisData
  }],
  yAxis: [{
    type: 'value',
    splitLine: {
      show: false
    },
    axisLine: {
      lineStyle: {
        color: '#90979c'
      }
    },
    axisTick: {
      show: false
    },
    axisLabel: {
      interval: 0
    },
    splitArea: {
      show: false
    }
  }],
  dataZoom: [{
    show: true,
    xAxisIndex: [0],
    bottom: 30,
    start: 10,
    end: 80,
    handleIcon: 'path://M306.1,413c0,2.2-1.8,4-4,4h-59.8c-2.2,0-4-1.8-4-4V200.8c0-2.2,1.8-4,4-4h59.8c2.2,0,4,1.8,4,4V413z',
    handleSize: '110%',
    handleStyle: {
      color: '#d3dee5'
    },
    textStyle: {
      color: '#fff'
    },
    borderColor: '#90979c'
  }, {
    type: 'inside',
    show: true,
    start: 1,
    end: 35
  }],
  series: [{
    name: Object.keys(data)[0],
    type: 'bar',
    stack: 'total',
    barMaxWidth: 35,
    barGap: '10%',
    itemStyle: {
      color: 'rgba(255,144,128,1)',
      label: {
        show: true,
        textStyle: {
          color: '#fff'
        },
        position: 'insideTop',
        formatter: function formatter(p) {
          return p.value > 0 ? p.value : '';
        }
      }
    },
    data: data[Object.keys(data)[0]]
  }, {
    name: Object.keys(data)[1],
    type: 'bar',
    stack: 'total',
    itemStyle: {
      color: 'rgba(0,191,183,1)',
      barBorderRadius: 0,
      label: {
        show: true,
        position: 'top',
        formatter: function formatter(p) {
          return p.value > 0 ? p.value : '';
        }
      }
    },
    data: data[Object.keys(data)[1]]
  }, {
    name: Object.keys(data)[2],
    type: 'line',
    stack: 'total',
    symbolSize: 10,
    symbol: 'circle',
    itemStyle: {
      color: 'rgba(252,230,48,1)',
      barBorderRadius: 0,
      label: {
        show: true,
        position: 'top',
        formatter: function formatter(p) {
          return p.value > 0 ? p.value : '';
        }
      }
    },
    data: data[Object.keys(data)[2]]
  }]
};

var MixedChart = /*#__PURE__*/function (_mixins) {
  _inherits(MixedChart, _mixins);

  var _super = _createSuper(MixedChart);

  function MixedChart() {
    _classCallCheck(this, MixedChart);

    return _super.apply(this, arguments);
  }

  _createClass(MixedChart, [{
    key: "mounted",
    value: function mounted() {}
  }, {
    key: "options",
    get: function get() {
      if (this.chartOption.legend) {
        this.chartOption.legend['data'] = Object.keys(this.chartData.data);
      }

      if (this.chartOption.xAxis) {
        this.chartOption.xAxis[0].data = this.chartData.xAxisData;
      }

      if (this.chartOption.series && Array.isArray(this.chartOption.series)) {
        this.chartOption.series[0] && (this.chartOption.series[0].name = Object.keys(this.chartData.data)[0], this.chartOption.series[0].data = this.chartData.data[Object.keys(this.chartData.data)[0]]);
        this.chartOption.series[1] && (this.chartOption.series[1].name = Object.keys(this.chartData.data)[1], this.chartOption.series[1].data = this.chartData.data[Object.keys(this.chartData.data)[1]]);
        this.chartOption.series[2] && (this.chartOption.series[2].name = Object.keys(this.chartData.data)[2], this.chartOption.series[2].data = this.chartData.data[Object.keys(this.chartData.data)[2]]);
      }

      return this.chartOption;
    }
  }]);

  return MixedChart;
}(mixins(BaseChart));

__decorate([Prop({
  default: function _default() {
    return defaultData;
  }
})], MixedChart.prototype, "chartData", void 0);

__decorate([Prop({
  default: function _default() {
    return defaultOption;
  }
})], MixedChart.prototype, "chartOption", void 0);

MixedChart = __decorate([Component({
  name: 'MixedChart',
  categrey: 'echart图表',
  zhName: '混合图',
  iconType: 'area-chart'
})], MixedChart);
export default withInstall(MixedChart);

==> vue-create-web-0.1.2.tgz: package/es/components/controls/echarts/MixedChart.js <==
import "core-js/modules/es.function.name.js";
import "core-js/modules/es.object.keys.js";
import _classCallCheck from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/classCallCheck";
import _createClass from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/createClass";
import _inherits from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/inherits";
import _createSuper from "F:/vue-create-web/node_modules/@babel/runtime/helpers/esm/createSuper";
import { __decorate } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import { mixins } from 'vue-class-component';
import BaseChart from './BaseChart';
import { withInstall } from '../../../util';

var xAxisData = function () {
  var data = [];

  for (var i = 1; i < 13; i++) {
    data.push(i + 'month');
  }

  return data;
}();

var data = {
  female: [709, 1917, 2455, 2610, 1719, 1433, 1544, 3285, 5208, 3372, 2484, 4078],
  male: [327, 1776, 507, 1200, 800, 482, 204, 1390, 1001, 951, 381, 220],
  average: [1036, 3693, 2962, 3810, 2519, 1915, 1748, 4675, 6209, 4323, 2865, 4298]
};
export var defaultData = {
  xAxisData: xAxisData,
  data: data
};
export var defaultOption = {
  backgroundColor: '#344b58',
  title: {
    text: 'statistics',
    top: '20',
    textStyle: {
      color: '#fff',
      fontSize: 22
    },
    subtextStyle: {
      color: '#90979c',
      fontSize: 16
    }
  },
  tooltip: {
    trigger: 'axis'
  },
  grid: {
    left: '5%',
    right: '5%',
    borderWidth: 0,
    top: 150,
    bottom: 95,
    textStyle: {
      color: '#fff'
    }
  },
  legend: {
    x: '5%',
    top: '10%',
    textStyle: {
      color: '#90979c'
    },
    data: Object.keys(data)
  },
  xAxis: [{
    type: 'category',
    axisLine: {
      lineStyle: {
        color: '#90979c'
      }
    },
    splitLine: {
      show: false
    },
    axisTick: {
      show: false
    },
    splitArea: {
      show: false
    },
    axisLabel: {
      interval: 0
    },
    data: xAxisData
  }],
  yAxis: [{
    type: 'value',
    splitLine: {
      show: false
    },
    axisLine: {
      lineStyle: {
        color: '#90979c'
      }
    },
    axisTick: {
      show: false
    },
    axisLabel: {
      interval: 0
    },
    splitArea: {
      show: false
    }
  }],
  dataZoom: [{
    show: true,
    xAxisIndex: [0],
    bottom: 30,
    start: 10,
    end: 80,
    handleIcon: 'path://M306.1,413c0,2.2-1.8,4-4,4h-59.8c-2.2,0-4-1.8-4-4V200.8c0-2.2,1.8-4,4-4h59.8c2.2,0,4,1.8,4,4V413z',
    handleSize: '110%',
    handleStyle: {
      color: '#d3dee5'
    },
    textStyle: {
      color: '#fff'
    },
    borderColor: '#90979c'
  }, {
    type: 'inside',
    show: true,
    start: 1,
    end: 35
  }],
  series: [{
    name: Object.keys(data)[0],
    type: 'bar',
    stack: 'total',
    barMaxWidth: 35,
    barGap: '10%',
    itemStyle: {
      color: 'rgba(255,144,128,1)',
      label: {
        show: true,
        textStyle: {
          color: '#fff'
        },
        position: 'insideTop',
        formatter: function formatter(p) {
          return p.value > 0 ? p.value : '';
        }
      }
    },
    data: data[Object.keys(data)[0]]
  }, {
    name: Object.keys(data)[1],
    type: 'bar',
    stack: 'total',
    itemStyle: {
      color: 'rgba(0,191,183,1)',
      barBorderRadius: 0,
      label: {
        show: true,
        position: 'top',
        formatter: function formatter(p) {
          return p.value > 0 ? p.value : '';
        }
      }
    },
    data: data[Object.keys(data)[1]]
  }, {
    name: Object.keys(data)[2],
    type: 'line',
    stack: 'total',
    symbolSize: 10,
    symbol: 'circle',
    itemStyle: {
      color: 'rgba(252,230,48,1)',
      barBorderRadius: 0,
      label: {
        show: true,
        position: 'top',
        formatter: function formatter(p) {
          return p.value > 0 ? p.value : '';
        }
      }
    },
    data: data[Object.keys(data)[2]]
  }]
};

var MixedChart = /*#__PURE__*/function (_mixins) {
  _inherits(MixedChart, _mixins);

  var _super = _createSuper(MixedChart);

  function MixedChart() {
    _classCallCheck(this, MixedChart);

    return _super.apply(this, arguments);
  }

  _createClass(MixedChart, [{
    key: "mounted",
    value: function mounted() {}
  }, {
    key: "options",
    get: function get() {
      if (this.chartOption.legend) {
        this.chartOption.legend['data'] = Object.keys(this.chartData.data);
      }

      if (this.chartOption.xAxis) {
        this.chartOption.xAxis[0].data = this.chartData.xAxisData;
      }

      if (this.chartOption.series && Array.isArray(this.chartOption.series)) {
        this.chartOption.series[0] && (this.chartOption.series[0].name = Object.keys(this.chartData.data)[0], this.chartOption.series[0].data = this.chartData.data[Object.keys(this.chartData.data)[0]]);
        this.chartOption.series[1] && (this.chartOption.series[1].name = Object.keys(this.chartData.data)[1], this.chartOption.series[1].data = this.chartData.data[Object.keys(this.chartData.data)[1]]);
        this.chartOption.series[2] && (this.chartOption.series[2].name = Object.keys(this.chartData.data)[2], this.chartOption.series[2].data = this.chartData.data[Object.keys(this.chartData.data)[2]]);
      }

      return this.chartOption;
    }
  }]);

  return MixedChart;
}(mixins(BaseChart));

__decorate([Prop({
  default: function _default() {
    return defaultData;
  }
})], MixedChart.prototype, "chartData", void 0);

__decorate([Prop({
  default: function _default() {
    return defaultOption;
  }
})], MixedChart.prototype, "chartOption", void 0);

MixedChart = __decorate([Component({
  name: 'MixedChart',
  categrey: 'echart图表',
  zhName: '混合图',
  iconType: 'area-chart'
})], MixedChart);
export default withInstall(MixedChart);
